Pre Test
-----------------------------------------------------

Please try to solve each of the following problems to the best of your ability.
It is **OK** to not know the correct answers!
Please do **not** refer to other resources.

Problems
==============

.. timed:: hparsons_learning_gain_sql_pretest_timed
   :timelimit: 10
   :noresult:
   :nofeedback:
   :nopause:

   .. selectquestion:: hparsons_lg_sql_pretest_timed_1
      :fromid: hparsons_lg_sql_test_bank_pre_select
      :points: 10

   .. selectquestion:: hparsons_lg_sql_pretest_timed_2
      :fromid: hparsons_lg_sql_test_bank_pre_update
      :points: 10

   .. selectquestion:: hparsons_lg_sql_pretest_timed_3
      :fromid: hparsons_lg_sql_test_bank_pre_join
      :points: 10

Thank You 🤗
============================
🎉 We appreciate your participation in our study.

If you have questions or feedback, or want to know more, please contact Zihan Wu (ziwu@umich.edu).
